@@ -310,7 +310,6 @@ static void
 anjuta_plugin_class_init (AnjutaPluginClass *class) 
 {
 	GObjectClass *object_class = (GObjectClass*) class;
-	GObjectClass *parent_class = g_type_class_peek_parent (class);
     
 	object_class->dispose = anjuta_plugin_dispose;
 	object_class->finalize = anjuta_plugin_finalize;
@@ -327,7 +326,7 @@ anjuta_plugin_class_init (AnjutaPluginClass *class)
 				      _("Anjuta Shell"),
 				      _("Anjuta shell that will contain the plugin"),
 				      ANJUTA_TYPE_SHELL,
-				      G_PARAM_READWRITE/* | G_PARAM_CONSTRUCT_ONLY*/)); /* Construct only does not work with libanjutamm */
+				      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 	plugin_signals[ACTIVATED_SIGNAL] =
 		g_signal_new ("activated",
 					G_TYPE_FROM_CLASS (object_class),
