@@ -180,6 +180,10 @@ breakpoint_item_update_from_debugger (BreakpointItem *bi, const IAnjutaDebuggerB
 	{
 		bi->bp.temporary = bp->temporary;
 	}
+	if (bp->type & IANJUTA_DEBUGGER_BREAKPOINT_WITH_PENDING)
+	{
+		bi->bp.pending = bp->pending;
+	}
 	if ((bp->type & IANJUTA_DEBUGGER_BREAKPOINT_WITH_ENABLE) &&
 		!(bi->changed & IANJUTA_DEBUGGER_BREAKPOINT_WITH_ENABLE))
 	{
@@ -448,6 +452,10 @@ breakpoints_dbase_update_in_treeview (BreakpointsDBase *bd, BreakpointItem *bi)
 	{
 		format = "temporary (%d)";
 	}
+	else if (bi->bp.pending)
+	{
+		format = "pending (%d)";
+	}
 	else 
 	{
 		format = "permanent (%d)";
