@@ -229,7 +229,8 @@ npw_druid_fill_summary_page (NPWDruid* druid)
 	GString* text;
 	GtkLabel* label;
 
-	text = g_string_new (_("<b>Confirm the following information:</b>\n\n"));
+	text = g_string_new (NULL);
+	g_string_append_printf (text, "<b>%s</b>\n\n", _("Confirm the following information:"));
 
 	/* The project type is translated too, it is something like
 	 * generic, GNOME applet, Makefile project... */
@@ -357,7 +358,7 @@ cb_druid_insert_project_page (gpointer value, gpointer user_data)
 
 /* Fill project selection page */
 static gboolean
-npw_druid_fill_selection_page (NPWDruid* druid)
+npw_druid_fill_selection_page (NPWDruid* druid, const gchar *directory)
 {
 	gchar* dir;
 	const gchar * const * sys_dir;
@@ -370,23 +371,31 @@ npw_druid_fill_selection_page (NPWDruid* druid)
 	/* Create list of projects */
 	druid->header_list = npw_header_list_new ();	
 	
-	/* Read project template in user directory,
-	 * normally ~/.local/share/anjuta/project,
-	 * the first template read override the others */
-	dir = g_build_filename (g_get_user_data_dir (), "anjuta", "project", NULL);
-	npw_header_list_readdir (&druid->header_list, dir);
-	g_free (dir);
-	
-	/* Read project template in system directory */	
-	for (sys_dir = g_get_system_data_dirs (); *sys_dir != NULL; sys_dir++)
+	if (directory != NULL)
 	{
-		dir = g_build_filename (*sys_dir, "anjuta", "project", NULL);
-		npw_header_list_readdir (&druid->header_list, PROJECT_WIZARD_DIRECTORY);
-		g_free (dir);
+		/* Read project template only in specified directory */
+		npw_header_list_readdir (&druid->header_list, directory);
 	}
+	else
+	{
+		/* Read project template in user directory,
+		 * normally ~/.local/share/anjuta/project,
+		 * the first template read override the others */
+		dir = g_build_filename (g_get_user_data_dir (), "anjuta", "project", NULL);
+		npw_header_list_readdir (&druid->header_list, dir);
+		g_free (dir);
+	
+		/* Read project template in system directory */	
+		for (sys_dir = g_get_system_data_dirs (); *sys_dir != NULL; sys_dir++)
+		{
+			dir = g_build_filename (*sys_dir, "anjuta", "project", NULL);
+			npw_header_list_readdir (&druid->header_list, dir);
+			g_free (dir);
+		}
 
-	/* Read anjuta installation directory */
-	npw_header_list_readdir (&druid->header_list, PROJECT_WIZARD_DIRECTORY);
+		/* Read anjuta installation directory */
+		npw_header_list_readdir (&druid->header_list, PROJECT_WIZARD_DIRECTORY);
+	}
 	
 	if (g_list_length (druid->header_list) == 0)
 	{
@@ -411,6 +420,7 @@ typedef struct _NPWDruidAddPropertyData
 	NPWDruid* druid;
 	guint row;
 	GtkTable *table;
+	GtkWidget *first_entry;
 } NPWDruidAddPropertyData;
 
 static void
@@ -440,17 +450,33 @@ cb_druid_add_property (NPWProperty* property, gpointer user_data)
 			gtk_widget_set_tooltip_text (entry, description);
 		}
 
-		/* Add label and entry */
-		gtk_table_resize (data->table, data->row + 1, 2);
 		label = gtk_label_new (npw_property_get_label (property));
 		gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 		gtk_misc_set_padding (GTK_MISC (label), 6, 6);
-		gtk_table_attach (data->table, label, 0, 1, data->row, data->row + 1,
-			(GtkAttachOptions)(GTK_FILL), (GtkAttachOptions)(0), 0, 0);
-		gtk_table_attach (data->table, entry, 1, 2, data->row, data->row + 1,
-			(GtkAttachOptions)(GTK_EXPAND|GTK_FILL), (GtkAttachOptions)(0), 0, 0);
 		
-		data->row++;
+		switch (npw_property_get_type (property))
+		{
+			case NPW_PACKAGE_PROPERTY:
+				gtk_table_resize (data->table, data->row + 2, 1);
+				gtk_table_attach (data->table, label, 0, 1, data->row, data->row + 1,
+				                  (GtkAttachOptions)(GTK_FILL), 0, 0, 0);
+				gtk_table_attach (data->table, entry, 0, 1, data->row + 1, data->row + 2,
+				                  (GtkAttachOptions)(GTK_EXPAND|GTK_FILL),
+				                  (GtkAttachOptions)(GTK_EXPAND|GTK_FILL), 0, 0);
+				data->row += 2;
+				break;
+			default:
+				/* Add label and entry */
+				gtk_table_resize (data->table, data->row + 1, 2);
+				gtk_table_attach (data->table, label, 0, 1, data->row, data->row + 1,
+				                  (GtkAttachOptions)(GTK_FILL), 0, 0, 0);
+				gtk_table_attach (data->table, entry, 1, 2, data->row, data->row + 1,
+				                  (GtkAttachOptions)(GTK_EXPAND|GTK_FILL), 0, 0, 0);
+				data->row++;
+		}
+		
+		/* Set first entry */
+		if (data->first_entry == NULL) data->first_entry = entry;
 	}
 };
 
@@ -472,7 +498,14 @@ npw_druid_fill_property_page (NPWDruid* druid, NPWPage* page)
 	data.druid = druid;
 	data.row = 0;
 	data.table = GTK_TABLE (npw_page_get_widget (page));
+	data.first_entry = NULL;
 	npw_page_foreach_property (page, (GFunc)cb_druid_add_property, &data);
+
+	/* Move focus on first entry */
+	if (data.first_entry != NULL)
+	{
+		gtk_container_set_focus_child (GTK_CONTAINER (data.table), data.first_entry);
+	}
 	
 	gtk_widget_show_all (widget);
 }
@@ -1008,7 +1041,7 @@ on_druid_finish (GtkAssistant* assistant, NPWDruid* druid)
 }
 
 static GtkWidget*
-npw_druid_create_assistant (NPWDruid* druid)
+npw_druid_create_assistant (NPWDruid* druid, const gchar *directory)
 {
 	AnjutaShell *shell;
 	GtkBuilder *builder;
@@ -1046,7 +1079,7 @@ npw_druid_create_assistant (NPWDruid* druid)
 	g_signal_connect(G_OBJECT(assistant), "key-press-event", G_CALLBACK(on_project_wizard_key_press_event), druid);
 
 	/* Setup project selection page */
-	if (!npw_druid_fill_selection_page (druid))
+	if (!npw_druid_fill_selection_page (druid, directory))
 	{
 		return NULL;
 	}
@@ -1117,7 +1150,7 @@ npw_druid_add_default_property (NPWDruid* druid)
  *---------------------------------------------------------------------------*/
 
 NPWDruid*
-npw_druid_new (NPWPlugin* plugin)
+npw_druid_new (NPWPlugin* plugin, const gchar *directory)
 {
 	NPWDruid* druid;
 
@@ -1138,7 +1171,7 @@ npw_druid_new (NPWPlugin* plugin)
 	druid->plugin = plugin;
 	druid->error_extra_widget = NULL;
 
-	if (npw_druid_create_assistant (druid) == NULL)
+	if (npw_druid_create_assistant (druid, directory) == NULL)
 	{
 		npw_druid_free (druid);
 		
